@@ -11,7 +11,8 @@ assign("settings",
        list(ops = TRUE, ns = TRUE,
             args = TRUE, func = FALSE,
             ipck = FALSE, S3 = TRUE, data = TRUE,
-            help = TRUE, argdb = TRUE),
+            help = TRUE, argdb = TRUE,
+            files = .Platform$OS.type == "windows"),
        env = .CompletionEnv)
 
 
